#include <iostream>
#include "svg.h"
#include <vector>
#include <string>
using namespace std;

const auto IMAGE_WIDTH = 400;
const auto IMAGE_HEIGHT = 300;
const auto TEXT_LEFT = 20;
const auto TEXT_BASELINE = 20;
const auto TEXT_WIDTH = 50;
const auto BIN_HEIGHT = 30;
const auto BLOCK_WIDTH = 10;

void
SvgBegin(double width, double height) {
    cout << "<?xml version='1.0' encoding='UTF-8'?>\n";
    cout << "<svg ";
    cout << "width='" << width << "' ";
    cout << "height='" << height << "' ";
    cout << "viewBox='0 0 " << width << " " << height << "' ";
    cout << "xmlns='http://www.w3.org/2000/svg'>\n";
}

void
SvgEnd() {
    cout << "</svg>\n";
}

void
SvgText(double left, double baseline, string text) {
    cout << "<text x='" << left << "' y='" << baseline << "' >" << text << "</text>\n";
}

void SvgRect(double x, double y, double width, double height, string stroke = "black", string fill = "black") {
    cout << "<rect x ='" << x << "' y ='" << y << "' width ='" << width << "' height ='" << height << "' stroke ='" << stroke << "' fill ='" << fill << "' />\n";
}

void
ShowHistogramSvg(const vector<size_t>& bins) {
    double top = 0;
    SvgBegin(400, 300);
    
    size_t MaxCount = 0;
    for (auto bin : bins) {
        if (MaxCount < bin) {
            MaxCount = bin;
        }
    }
    int k = (IMAGE_WIDTH - TEXT_WIDTH) / MaxCount * BLOCK_WIDTH;

    if (k > 1) k = 1;

    for (size_t bin : bins) {
        bin = bin * k;
        const double bin_width = BLOCK_WIDTH * bin;
        SvgText(TEXT_LEFT, top + TEXT_BASELINE, to_string(bin));
        SvgRect(TEXT_WIDTH, top, bin_width, BIN_HEIGHT, "red", "#FF69B4");
        top += BIN_HEIGHT;
    }
    SvgEnd();
}


